==> dde-shell_2.0.15.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_ja.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ja">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>無線LAN ON</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>無線LAN OFF</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>Caps Lock ON</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>Caps Lock OFF</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>テンキー ON</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>テンキー OFF</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>タッチパッド ON</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>タッチパッド OFF</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>タッチパッド トグル</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Fn トグル</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>機内モード ON</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>機内モードOFF</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>バランス</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>省電力</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>高パフォーマンス</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>ウィンドウ エフェクトが有効化されました</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>ウィンドウ エフェクト が無効化されました</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>ウィンドウ エフェクトを有効化できませんでした</translation>
    </message>
    <message>
        <source>Microphone off</source>
        <translation>マイクOFF</translation>
    </message>
    <message>
        <source>Microphone on</source>
        <translation>マイクON</translation>
    </message>
</context>
</TS>

==> dde-shell_2.0.19.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_ja.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ja">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>無線LAN ON</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>無線LAN OFF</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>Caps Lock ON</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>Caps Lock OFF</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>テンキー ON</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>テンキー OFF</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>タッチパッド ON</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>タッチパッド OFF</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>タッチパッド トグル</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Fn トグル</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>機内モード ON</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>機内モードOFF</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>バランス</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>省電力</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>高パフォーマンス</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>ウィンドウ エフェクトが有効化されました</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>ウィンドウ エフェクト が無効化されました</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>ウィンドウ エフェクトを有効化できませんでした</translation>
    </message>
    <message>
        <source>Microphone off</source>
        <translation>マイクOFF</translation>
    </message>
    <message>
        <source>Microphone on</source>
        <translation>マイクON</translation>
    </message>
    <message>
        <source>Camera on</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Camera off</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
